local mod = ...



-- Building Asset Processor -------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/MarketCart1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Assets -------------------------------------------------------------------------------------
-- mod:registerAssetId("models/MarketCart1.fbx/Prefab/Cart.Part", "PREFAB_MARKETCART_CART")



-- Particle: Honey Cart bees -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/MarketCart1.fbx/Prefab/HONEY.PART/BeeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_BEEKEEPER_BEES",
	IsPlaying = true,
	IsEmitting = true
})

mod:registerPrefabComponent("models/MarketCart1.fbx/Prefab/HONEY.PART/BeeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})



-- Building Progress List -------------------------------------------------------------------------------------
mod:overrideAsset({
    Id = "DEFAULT_BALANCING",
    BuildingProgressList = {
        Action = "APPEND",
        "BUILDING_PROGRESS_LIST_MARKETCART"
    }
})

mod:registerAsset({
    DataType = "BUILDING_PROGRESS_LIST",
    Id = "BUILDING_PROGRESS_LIST_MARKETCART",
    ProgressList = {
        {
            UnlockName = "UNLOCK_MARKETCART_BERRIES",
            AssetUnlockableBuildingPartList = {
                "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_BERRIES",
            },
            IsManuallyUnlocked = false,
            VillagerRequired = {
                Status = "NEWCOMER",
                Quantity = 10
            }
        },
        {
            UnlockName = "UNLOCK_MARKETCART_BREAD",
            AssetUnlockableBuildingPartList = {
                "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_BREAD",
            },
            IsManuallyUnlocked = false,
            VillagerRequired = {
                Status = "SERF",
                Quantity = 15
            }
        },
        {
            UnlockName = "UNLOCK_MARKETCART_FISH",
            AssetUnlockableBuildingPartList = {
                "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_FISH",
            },
            IsManuallyUnlocked = false,
            VillagerRequired = {
                Status = "SERF",
                Quantity = 18
            }
        },
        {
            UnlockName = "UNLOCK_MARKETCART_CHEESE",
            AssetUnlockableBuildingPartList = {
                "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_CHEESE",
            },
            IsManuallyUnlocked = false,
            VillagerRequired = {
                Status = "COMMONER",
                Quantity = 5
            }
        },
        {
            UnlockName = "UNLOCK_MARKETCART_HONEY",
            AssetUnlockableBuildingPartList = {
                "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_HONEY",
            },
            IsManuallyUnlocked = false,
            VillagerRequired = {
                Status = "CITIZEN",
                Quantity = 10
            }
        },
    }
})



-- Register cart -------------------------------------------------------------------------------------
local function registerCart(idResource, nameSetList, typeResource, listPrereq)

    -- Resource
    mod:overrideAsset({
        Id = idResource,
        ResourceTypeList = { Action = "APPEND", typeResource },
    })

    -- Assets
    mod:registerAssetId("models/MarketCart1.fbx/Prefab/" .. idResource .. ".PART", "PREFAB_MARKETCART_" .. idResource)

    -- Paths
    mod:registerAssetId("models/MarketCart1.fbx/Prefab/" .. idResource .. ".PART/PATH_A_1." .. idResource, "PATH_MARKETCART_" .. idResource .. "_1")
    mod:registerAssetId("models/MarketCart1.fbx/Prefab/" .. idResource .. ".PART/PATH_B_1." .. idResource, "PATH_MARKETCART_" .. idResource .. "_3")
    mod:registerAssetId("models/MarketCart1.fbx/Prefab/" .. idResource .. ".PART/PATH_C_1." .. idResource, "PATH_MARKETCART_" .. idResource .. "_4")
    mod:registerAssetId("models/MarketCart1.fbx/Prefab/" .. idResource .. ".PART/PATH_D_1." .. idResource, "PATH_MARKETCART_" .. idResource .. "_5")

    mod:registerPrefabComponent("models/MarketCart1.fbx/Prefab/" .. idResource .. ".PART", {
        DataType = "COMP_BUILDING_PART",
        PathList = {
            {
                PathType = BUILDING_PATH_TYPE.DEFAULT,
                WayPointList = { "PATH_MARKETCART_" .. idResource .. "_1" }
            },
            {
                PathType = BUILDING_PATH_TYPE.PICKUP,
                WayPointList = { "PATH_MARKETCART_" .. idResource .. "_3" }
            },
            {
                PathType = BUILDING_PATH_TYPE.PICKUP,
                WayPointList = { "PATH_MARKETCART_" .. idResource .. "_4" }
            },
            {
                PathType = BUILDING_PATH_TYPE.PICKUP,
                WayPointList = { "PATH_MARKETCART_" .. idResource .. "_5" }
            },
        }
    })

    -- Building Function
    mod:registerAsset({
        DataType = "BUILDING_FUNCTION_MARKET",
        Id = "BUILDING_FUNCTION_MARKETCART_" .. idResource,
        Name = "BUILDING_FUNCTION_MARKETCART_" .. idResource .. "_NAME",
        WorkerCapacity = 1,
        RelatedJob = {
            Job = "MARKET_TENDER",
            Behavior = "BEHAVIOR_MARKET_TENDING"
        },
        TypeList = { typeResource },
        IsOverrideCapacity = true,
        CapacityPerSlot = 50,
    })

    -- Unlockable building part list
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_" .. idResource,
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_" .. nameSetList,
                BuildingPartList = {
                    "BUILDING_PART_MARKETCART_" .. idResource,
                }
            },
        },
        PrerequisiteUpgrades = listPrereq,
    })

    -- Building part
    mod:registerAsset({
        DataType = "BUILDING_PART",
        Id = "BUILDING_PART_MARKETCART_" .. idResource,
        Name = "BUILDING_PART_MARKETCART_" .. idResource .. "_NAME",
        -- Category = "MARKET_STALL",
        ConstructorData = {
            DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
            CoreObjectPrefab = "PREFAB_MARKETCART_" .. idResource,
            MiniatureConfig = {
                ClipUnderGround = false,
                GroupHeight = 0.0,
                CameraPosition = { 0, 0, 0 },
                OrientationOffset = 0.0,
                CameraPitchOffset = 20.0
            },
        },
        AssetBuildingFunction = "BUILDING_FUNCTION_MARKETCART_" .. idResource,
        BuildingZone = {
            ZoneEntryList = {
                {
                    Polygon = polygon.createRectangle( {1.1, 1.1}, {0, 0} ),
                    Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true }
                },
            },
        },
        Cost = {
            BuildRightTaxes = {	{ Resource = "GOLD_COINS", Quantity = 5 } },
            UpkeepCost = { { Resource = "GOLD_COINS", Quantity = 1 } },
            ResourceNeededList = {
                {
                    { Resource = "PLANK", Quantity = 2 },
                },
            }
        },
        DesirabilityModifiers = { {
            Desirability = "DESIRABILITY_RESIDENTIAL",
            Type = "ADD",
            Radius = 25.0,
            Value = 0.5
        } }
    })


end

registerCart("BERRIES", "FOOD", "RESOURCE_TYPE_BERRIES", nil)
registerCart("BREAD", "FOOD", "RESOURCE_TYPE_BREAD", nil)
registerCart("CHEESE", "FOOD", "RESOURCE_TYPE_CHEESE", nil)
registerCart("FISH", "FOOD", "RESOURCE_TYPE_FISH", {"UNLOCKABLE_LABOUR_FISHING_HUT"})
registerCart("HONEY", "LUXURY", "RESOURCE_TYPE_HONEY", nil)



-- Building: Market (Override) -------------------------------------------------------------------------------------
mod:overrideAsset({
    Id = "MONUMENT_MARKET",
	RequiredPartList = {},
	-- BuildingPartSetList = {
    --     Action = "APPEND",
	-- 	{
	-- 		Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
	-- 		BuildingPartList = {
	-- 			"BUILDING_PART_MARKET_FOOD_STALL",
    --         },
	-- 	},
	-- 	{
	-- 		Name = "BUILDING_PART_SET_LIST_MARKET_GOODS",
	-- 		BuildingPartList = { 
	-- 			"BUILDING_PART_MARKET_GOODS_STALL",
	-- 		},
	-- 	},
	-- 	{
	-- 		Name = "BUILDING_PART_SET_LIST_MARKET_LUXURY",
	-- 		BuildingPartList = { 
	-- 			"BUILDING_PART_MARKET_LUXURY_STALL",
	-- 		},
	-- 	},
	-- 	{
	-- 		Name = "BUILDING_PART_SET_LIST_MARKET_NEEDS",
	-- 		BuildingPartList = {
	-- 		},
	-- 	},
	-- 	{
	-- 		Name = "DECORATIVE",
	-- 		BuildingPartList = { 
	-- 			"BUILDING_PART_MARKET_RED_TENT",
	-- 			"BUILDING_PART_MARKET_BLUE_TENT",
    --             "BUILDING_PART_MARKET_GREEN_TENT",
    --             "BUILDING_PART_MARKET_FOOD_SIGN",
    --             "BUILDING_PART_MARKET_GOODS_SIGN",
    --             "BUILDING_PART_MARKET_LUXURY_SIGN",
    --             "BUILDING_PART_MARKET_BARRELS",
    --             "BUILDING_PART_MARKET_BENCH",
    --             "BUILDING_PART_MARKET_FENCE",
	-- 		}
	-- 	},
    -- },
})



-- If Fuel is loaded, add the fuelmonger cart
if (foundation.isModLoaded("7b6dabf2-3523-46ff-ba47-caca86189784")) then

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_FUELMONGER",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_FUELMONGER",
                },
                IsManuallyUnlocked = true,
                VillagerRequired = {
                    Status = "NEWCOMER",
                    Quantity = 8
                }
            },
        }
    })

    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_FUELMONGER",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_NEEDS",
                BuildingPartList = {
                    "FUELCART_PART",
                }
            },
        }
    })

end



-- If Security is loaded, add the Town Crier
if (foundation.isModLoaded("99ee3b3b-f103-41f0-a725-bc466a2fc6de")) then

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_TOWNCRIER",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_TOWNCRIER",
                },
                IsManuallyUnlocked = true,
                VillagerRequired = {
                    Status = "NEWCOMER",
                    Quantity = 8
                }
            },
        }
    })
    
    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_TOWNCRIER",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_NEEDS",
                BuildingPartList = {
                    "BUILDING_PART_SECURITY_CRIER1",
                }
            },
        }
    })

end



-- If Vegetable and Poultry is loaded, add the carts (OLD VERSION)
if (foundation.isModLoaded("fe9d3810-8afc-40e5-9fc9-bdbd3421e8cb")) then

    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_POULTRY",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "POULTRYCART_PART",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_EGG",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "POULTRYCART_EGG_PART",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_VEGETABLE",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "VEGETABLECART_PART",
                }
            },
        }
    })

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_POULTRY",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_POULTRY",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "NEWCOMER",
                    Quantity = 10
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_EGG",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_EGG",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "NEWCOMER",
                    Quantity = 10
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_VEGETABLE",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_VEGETABLE",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "NEWCOMER",
                    Quantity = 16
                }
            },
        }
    })

end



-- If Vegetable and Poultry is loaded, add the carts (NEW VERSION)
if (foundation.isModLoaded("c8b63172-5b6d-45eb-9fab-a40c8ecd9947")) then

    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_POULTRY",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUILDING_PART_POULTRYFARM_MARKETCART_RESOURCE_POULTRY",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_EGG",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUILDING_PART_POULTRYFARM_MARKETCART_BV1_EGG",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_VEGETABLE",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUILDING_PART_VEGETABLEFARM_MARKETCART",
                }
            },
        }
    })

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_POULTRY",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_POULTRY",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "NEWCOMER",
                    Quantity = 10
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_EGG",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_EGG",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "NEWCOMER",
                    Quantity = 10
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_VEGETABLE",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_VEGETABLE",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "NEWCOMER",
                    Quantity = 16
                }
            },
        }
    })

end



-- If Livestock is loaded, add the carts and tables (OLD VERSION)
if (foundation.isModLoaded("debb69c1-eb38-4183-9739-fbafa47568b4")) then
    mod:overrideAsset({ Id = "BUILDING_PART_LIVESTOCK_CREAMERY_TABLE", Name = "BUILDING_PART_LIVESTOCK_CREAMERYTABLE_NAME" })
    mod:overrideAsset({ Id = "BUTCHERSHOP_COUNTER_PART", Name = "BUILDING_PART_LIVESTOCK_BUTCHERTABLE_NAME" })
    mod:overrideAsset({ Id = "CHANDLER_COUNTER_PART", Name = "BUILDING_PART_LIVESTOCK_CHANDLERTABLE_NAME" })

    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_MILK",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "MILKCART_PART",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_BUTTER",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUILDING_PART_LIVESTOCK_CREAMERY_TABLE",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_MEAT",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUTCHERSHOP_COUNTER_PART",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_CHANDLER",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_GOODS",
                BuildingPartList = {
                    "CHANDLER_COUNTER_PART",
                }
            },
        }
    })

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_MILK",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_MILK",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 5
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_BUTTER",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_BUTTER",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 5
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_MEAT",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_MEAT",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 5
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_CHANDLER",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_CHANDLER",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 5
                }
            },    
        }
    })

end



-- If Livestock is loaded, add the carts and tables (NEW VERSION)
if (foundation.isModLoaded("f6361b64-05d3-4ab5-a2db-b3b60dc4d307")) then
    -- mod:overrideAsset({ Id = "BUILDING_PART_LIVESTOCKFARM_CREAMERYMARKET", Name = "BUILDING_PART_LIVESTOCKFARM_CREAMERYMARKET_NAME" })
    -- mod:overrideAsset({ Id = "BUTCHERSHOP_COUNTER_PART", Name = "BUILDING_PART_LIVESTOCK_BUTCHERTABLE_NAME" })
    -- mod:overrideAsset({ Id = "CHANDLER_COUNTER_PART", Name = "BUILDING_PART_LIVESTOCK_CHANDLERTABLE_NAME" })

    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_MILK",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUILDING_PART_LIVESTOCKFARM_MILKCART",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_BUTTER",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUILDING_PART_LIVESTOCKFARM_CREAMERYMARKET",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_MEAT",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUILDING_PART_LIVESTOCKFARM_BUTCHERMARKET",
                }
            },
        }
    })

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_CHANDLER",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_GOODS",
                BuildingPartList = {
                    "BUILDING_PART_LIVESTOCKFARM_CHANDLER_MARKET",
                }
            },
        }
    })

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_MILK",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_MILK",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 1
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_BUTTER",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_BUTTER",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 1
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_MEAT",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_MEAT",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 1
                }
            },
            {
                UnlockName = "UNLOCK_MARKETCART_CHANDLER",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_CHANDLER",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 1
                }
            },    
        }
    })

end



-- If Orchard is loaded, add the apple cart
if (foundation.isModLoaded("f252f14d-ca1d-4d02-97ca-46581d4b567d")) then

    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_FRUIT",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_FOOD",
                BuildingPartList = {
                    "BUILDING_PART_ORCHARD_CART",
                }
            },
        }
    })

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_FRUIT",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_FRUIT",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 1
                }
            },
        }
    })

end



-- If Furniture is loaded, add the table
if (foundation.isModLoaded("4a8d3ff2-60af-4c75-8950-33e990975862")) then

    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_FURNITURE",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_GOODS",
                BuildingPartList = {
                    "JOINERWORKSHOPCOUNTER_PART",
                }
            },
        }
    })

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_FURNITURE",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_FURNITURE",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "COMMONER",
                    Quantity = 5
                }
            },
        }
    })

end



-- If Basic Materials is loaded, add the pottery cart
if (foundation.isModLoaded("d757c3ab-0148-4290-aa51-5559329f5640")) then

    -- Unlockable
    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_POTTERY",
        AssetBuilding = "MONUMENT_MARKET",
        BuildingPartSetList = {
            {
                Name = "BUILDING_PART_SET_LIST_MARKET_GOODS",
                BuildingPartList = {
                    "BUILDING_PART_BASIC_POTTERCART",
                }
            },
        }
    })

    -- Building progress list
    mod:overrideAsset({
        Id = "BUILDING_PROGRESS_LIST_MARKETCART",
        ProgressList = {
            Action = "APPEND",
            {
                UnlockName = "UNLOCK_MARKETCART_POTTERY",
                AssetUnlockableBuildingPartList = {
                    "UNLOCKABLE_BUILDING_PART_LIST_MARKETCART_POTTERY",
                },
                IsManuallyUnlocked = false,
                VillagerRequired = {
                    Status = "SERF",
                    Quantity = 10
                }
            },
        }
    })

end
